@@ -1,9 +1,9 @@
-from abc import ABC, abstractmethod
+from .models.model import ClientModel
 import json
 
 # create a base class for the cache client
-class CacheClient(ABC):
-    def __init__(self, cacheFileFullPath, force=False):
+class CacheClient(ClientModel):
+    def __init__(self, cacheFileFullPath, force=False, *args, **kwargs):
         self.cacheFileFullPath = cacheFileFullPath
         try:
             self.dict = self.__loads()
@@ -14,6 +14,7 @@ class CacheClient(ABC):
             else:
                 self.save({})
                 self.dict = self.__loads()
+        super().__init__(self.dict, *args, **kwargs)
     
     def __loads(self):
         return json.loads(open(self.cacheFileFullPath).read())
@@ -26,6 +27,6 @@ class CacheClient(ABC):
     def dumps(self, data:dict, indent=4, sort_keys=False):
         return json.dumps(data, indent=4, sort_keys=False)
 
-    def set(self, key, value):
+    def set(self, key:str, value:str):
         self.dict[key] = value
         self.save(self.dict)
\ No newline at end of file
